==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ListMouseMotionHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ListMouseMotionHandler

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 72f3c2a8cbe5ae24 javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler

// header file dependencies
// @dep_header java_awt_event_MouseMotionAdapter

#include "java/awt/event/MouseMotionAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method_info$mouseMoved$9e3a895f548fc637;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods {
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24ListMouseMotionHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$ListMouseMotionHandler

// class file dependencies
// @dep_class 7be49a9ebc11cb6e java_awt_event_MouseMotionAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 72f3c2a8cbe5ae24 javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler

// header file dependencies
// @dep_header java_awt_event_MouseMotionAdapter

#include "java/awt/event/MouseMotionAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$method_info$mouseMoved$9e3a895f548fc637;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods {
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_MouseMotionAdapter$vmethods	java_awt_event_MouseMotionAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
    _jc_java_awt_event_MouseMotionAdapter$sub_refs	java_awt_event_MouseMotionAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_MouseMotionAdapter$sub_nonrefs	java_awt_event_MouseMotionAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24ListMouseMotionHandler_H_ */
